<?php
// $Id: settings.inc,v 1.1.2.9 2010/07/06 06:25:41 pobster Exp $

/**
 * @file
 * Settings file for Gamertags module.
 */

/**
 * Administrative setting callback.
 */
function gamertags_settings() {
  $form['collect'] = array(
    '#type' => 'fieldset',
    '#title' => t('Usage'),
    '#description' => t('Collect and Display:'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#theme' => 'gamertags_collect',
  );
  $form['collect']['checkbox']['gamertags_collect_xbox'] = array(
    '#type' => 'checkbox',
    '#title' => t("Xbox Gamertags"),
    '#default_value' => variable_get('gamertags_collect_xbox', TRUE),
  );
  $form['collect']['weight']['gamertags_weight_xbox'] = array(
    '#type' => 'weight',
    '#delta' => 50,
    '#default_value' => variable_get('gamertags_weight_xbox', 0),
  );
  $form['collect']['checkbox']['gamertags_collect_psn'] = array(
    '#type' => 'checkbox',
    '#title' => t("Playstation Gamertags"),
    '#default_value' => variable_get('gamertags_collect_psn', TRUE),
  );
  $form['collect']['weight']['gamertags_weight_psn'] = array(
    '#type' => 'weight',
    '#delta' => 50,
    '#default_value' => variable_get('gamertags_weight_psn', 0),
  );
  $form['collect']['checkbox']['gamertags_collect_wii'] = array(
    '#type' => 'checkbox',
    '#title' => t("Wii Friend Codes"),
    '#default_value' => variable_get('gamertags_collect_wii', TRUE),
  );
  $form['collect']['weight']['gamertags_weight_wii'] = array(
    '#type' => 'weight',
    '#delta' => 50,
    '#default_value' => variable_get('gamertags_weight_wii', 0),
  );
  $form['collect']['checkbox']['gamertags_collect_steam'] = array(
    '#type' => 'checkbox',
    '#title' => t("Steam Gamertags"),
    '#default_value' => variable_get('gamertags_collect_steam', TRUE),
  );
  $form['collect']['weight']['gamertags_weight_steam'] = array(
    '#type' => 'weight',
    '#delta' => 50,
    '#default_value' => variable_get('gamertags_weight_steam', 0),
  );
  $form['settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['settings']['gamertags_on_registration'] = array(
    '#type' => 'checkbox',
    '#title' => t("Ask for Gamertags on registration screen"),
    '#description' => t("Check this if you want users to be able to input their Gamertags on the user registration page as well as from their user account pages after they've registered."),
    '#default_value' => variable_get('gamertags_on_registration', TRUE),
  );
  $form['settings']['gamertags_debunk_ms'] = array(
    '#type' => 'checkbox',
    '#title' => t("Don't use Xbox.com for Xbox gamercard"),
    '#description' => t("If you use Xbox.com then you have to be happy with Microsofts 'solution' of having your Gamertags inside iframes.  Checking this box will use Gamertags from MyGamercard.net instead of official (but iframed) ones."),
    '#default_value' => variable_get('gamertags_debunk_ms', FALSE),
  );
  $form['settings']['gamertags_use_mapwii'] = array(
    '#type' => 'checkbox',
    '#title' => t("Use mapwii.com for Wii Friend Codes"),
    '#description' => t("Check this box to allow users wii friend codes to link through to the mapwii.com friend code repository."),
    '#default_value' => variable_get('gamertags_use_mapwii', FALSE),
  );
  $form['urls'] = array(
    '#type' => 'fieldset',
    '#title' => t('Gamertag URLs'),
    '#description' => t("You should never need to change these settings but if you do, note that the URL needs to be fully formed and it <strong>must</strong> contain <strong>ONE</strong> string replacement symbol '<strong>%s</strong>' which will be where the console username is swapped in.  See the defaults for examples of usage."),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['urls']['gamertags_xbox_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Xbox (Microsoft) URL'),
    '#default_value' => variable_get('gamertags_xbox_url', "http://gamercard.xbox.com/%s.card"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_mygamercard_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Xbox (MyGamerCard) URL'),
    '#default_value' => variable_get('gamertags_mygamercard_url', "http://card.mygamercard.net/%s.png"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_psn_eu_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Playstation Network (European) URL'),
    '#default_value' => variable_get('gamertags_psn_eu_url', "http://mypsn.eu.playstation.com/psn/profile/%s.jpg"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_psn_us_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Playstation Network (American) URL'),
    '#default_value' => variable_get('gamertags_psn_us_url', "http://fp.profiles.us.playstation.com/playstation/psn/pid/%s.png"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_wii_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Wii URL'),
    '#default_value' => variable_get('gamertags_wii_url', "http://mapwii.com/wii-number/member.cfm?wii_number=%s"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_steam_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Steam Card URL'),
    '#default_value' => variable_get('gamertags_steam_url', "http://steamcard.com/do/modern/%s.png"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form = system_settings_form($form);
  $form['#validate'][] = 'gamertags_settings_validate';
  $form['#theme'] = 'gamertags_settings';
  return $form;
} // gamertags_settings

/**
 * Form validation for checking URLs contain at least one string replacement symbol.
 */
function gamertags_settings_validate($form, &$form_state) {
  foreach (element_children($form['urls']) as $key) {
    if (!preg_match("/%s/", $form_state['values'][$key])) {
      form_set_error($key, t("Error, URL must contain a string replacement symbol i.e. '%s'"));
    }
    elseif (preg_match_all("/(%s+)/", $form_state['values'][$key], $matches) && count($matches[0]) != 1) {
      form_set_error($key, t("Error, URL must contain only ONE string replacement symbol i.e. '%s'"));
    }
  }
} // gamertags_settings__validate

/**
 * Themes output for the admin settings form.
 */
function theme_gamertags_settings($form) {
  drupal_add_js(drupal_get_path('module', 'gamertags') .'/misc/settings.js');
  $output = drupal_render($form['collect']);
  $output .= drupal_render($form['settings']);
  // Append messagebox to the fieldset description.
  $form['urls']['#description'] .= '<div id="gamertags_message"'. (_gamertags_test_any() ? '' : ' class="error"') .'>'. (_gamertags_test_any() ? '' : t('No Gamertags are currently set to be displayed.')) .'</div>';
  // If there's something in the messagebox, then don't collapse the fieldset (i.e. display the message).
  if (!_gamertags_test_any()) {
    $form['urls']['#collapsed'] = FALSE;
  }
  $output .= drupal_render($form['urls']);
  // Render any remaining form elements.
  $output .= drupal_render($form);
  return $output;
} // theme_gamertags_settings

/**
 * Themes output for the collect and display settings.
 */
function theme_gamertags_collect($form) {
  drupal_add_css(drupal_get_path('module', 'gamertags') .'/misc/gamertags.css');
  $rows = array();
  foreach (element_children($form['checkbox']) as $key) {
    $rows[] = array(
        drupal_render($form['checkbox'][$key]),
        drupal_render($form['weight'][preg_replace("/collect/", 'weight', $key)]),
    );
  }
  return '<div id="gamertags-collect-wrapper">'. theme('table', array(t('Gamertag'), t('Weight')), $rows, array('id' => "gamertags-collect")) .'</div>';
} // theme_gamertags_collect